# Copyright (C) 2010, 2011 Linaro Limited
#
# Author: Zygmunt Krynicki <zygmunt.krynicki@linaro.org>
#
# This file is part of LAVA Server.
#
# LAVA Server is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License version 3
# as published by the Free Software Foundation
#
# LAVA Server is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with LAVA Server.  If not, see <http://www.gnu.org/licenses/>.

from django.contrib import admin

from lava_projects.models import Project, ProjectFormerIdentifier


class ProjectAdmin(admin.ModelAdmin):

    list_display = (
        '__unicode__', 'identifier', 'registered_by',
        'registered_on', 'is_public', 'owner')


class ProjectFormerIdentifierAdmin(admin.ModelAdmin):

    list_display = (
        'former_identifier', 'project', 'renamed_on', 'renamed_by')


admin.site.register(Project, ProjectAdmin)
admin.site.register(ProjectFormerIdentifier, ProjectFormerIdentifierAdmin)
